==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-locale/lxqt-config-locale_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>&amp;Region:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Detaljerede indstillinger</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Tal:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Tid:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Måleenheder:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Sammenligning og sortering:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Eksempler&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Tal:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Måleenheder:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>Ingen ændring</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>Formatindstillinger ændret</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation>Gem indstillingerne? (de træder i kraft næste gang du logger ind)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>Imperial UK</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>Imperial US</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="38"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt-sprogkonfiguraton</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="43"/>
        <source>Locale Settings</source>
        <translation>Sprogindstillinger</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-locale/lxqt-config-locale_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>&amp;Region:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Detaljerede indstillinger</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Tal:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Tid:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Måleenheder:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Sammenligning og sortering:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Eksempler&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Tal:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Måleenheder:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>Ingen ændring</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>Formatindstillinger ændret</translation>
    </message>
    <message>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation type="vanished">Gem indstillingerne? (de træder i kraft næste gang du logger ind)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Vil du gemme dine ændringer? De træder i kraft næste gang du logger ind.</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>Imperial UK</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>Imperial US</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>Metrisk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt-sprogkonfiguraton</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Sprogindstillinger</translation>
    </message>
</context>
</TS>
